%% 
%% This is file `thema.cls',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% thesis.dtx  (with options: `thema')
%% 
%% Copyright (C) 1991, 1996 by Wenzel Matiaske, mati1831@perform.ww.tu-berlin.de 
%% 
%% You are not allowed to distribute this file without the 
%% original source thesis.dtx. For distribution of the 
%% sources see the copyright notice in the file thesis.dtx. 
%% 
\def\filename{thema}
\def\fileversion{1.0g}
\def\filedate{1996/25/01}
\def\docdate{1995/25/01}
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{thema}[\filedate\space\fileversion\space%
       LaTeX document class (wm).]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{thesis}}
\ProcessOptions
\LoadClass[thema]{thesis}
\endinput
%% 
%% End of file `thema.cls'.
